import { useState, useEffect } from "react";

export default function CountDownProgressbar({ percentage, value, maxValue, minValue }) {
    const [error, setError] = useState(false);
    const [progress, setProgress] = useState(0);

    useEffect(() => {
        if (
            typeof percentage === "number" &&
            percentage <= 100 &&
            percentage >= 0
        ) {
            setProgress(percentage);
        } else if (isNaN(value) || isNaN(maxValue) || isNaN(minValue)) {
            setError(true);
        } else if (value >= minValue && value <= maxValue) {
            setProgress((value / (maxValue - minValue)) * 100);
        } else if (isNaN(percentage) || percentage < 0 || percentage > 100) {
            setError(true);
            
        } else {
            setError(true);
        }
    }, [percentage, value, maxValue, minValue]);

    return (
        <>
            <div className="progress-bar">
                {!error && (
                    <div
                        className="loading-progress"
                        style={{ width: progress + "%" }}
                    >
                        {value} {' '}ثانیه
                    </div>
                )}
                {error && <div className="error">⚠️</div>}
            </div>
        </>
    );
}